CLI module for trojan-server.
This module provides the command-line interface that can be used either as a standalone binary or as a subcommand of the main trojan-rs CLI.
Structs
- Server
Args - Trojan server CLI arguments.
Functions
- run
- Run the trojan server with the given arguments.