run

Function run 

pub async fn run(args: ServerArgs) -> Result<(), Box<dyn Error>>
Run the trojan server with the given arguments.

This is the main entry point for the server CLI, used by both the standalone binary and the unified trojan-rs CLI.